class CollectionBuilder < Builder
  ##
  # Receive a list of ids and return a list of collections
  # Each element, must be a Hash with rid and last_modified
  #
  # Example:
  #   collection = CollectionBuilder.build [{'rid' => '#14:15', 'last_modified' => '2015-02-10 15:30'}]
  #
  # If the last_modified param is null, the object will be always reconstructed and updated in the cache
  def self.build(collections = [])
    super(collection_repository, collections, true, 'rid')
  end

  def self.build_from_orientdb(args = {})
    super(args) do
      learning_objects = args['learning_objects'].nil? ? [] : LearningObjectBuilder.build(map_rid_to_object(args['learning_objects']))
      obj = Orientdb::Collection.new(
        learning_objects: learning_objects,
        privacy: args['privacy'],
        id: args['@rid'],
        name: args['name']
      )
      obj.owner = collection_repository.owner(args['@rid'])
      obj.created_at = DateTime.strptime(args['created_at'], "%Y-%m-%d %H:%M:%S") unless args['created_at'].nil?
      obj.last_modified = DateTime.strptime(args['last_modified'], "%Y-%m-%d %H:%M:%S") unless args['last_modified'].nil?
      obj
    end
  end
end
